package pl.elzab.virtualcomsample;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.hardware.usb.UsbDevice;
import android.hardware.usb.UsbManager;
import android.util.Log;

/**
 * broadcast receiver for receiving usb permission
 * @author ElzabSoft
 * @version 1.01
 */
public class MyBroadcastReceiver extends BroadcastReceiver {
    /** usb permission exemplary name */
    public final String ACTION_USB_PERMISSION = "pl.elzab.virtualcomsample.USB_PERMISSION";
    /** tag for logging */
    public final String TAG = "ElzabUSB";

    /** method that handles intent broadcasts
     * @param context application context
     * @param intent intent
     */
    @Override
    public void onReceive(Context context, Intent intent) {
        String action = intent.getAction();
        if (ACTION_USB_PERMISSION.equals(action)) {
            synchronized (this) {
                UsbDevice device = (UsbDevice)intent.getParcelableExtra(UsbManager.EXTRA_DEVICE);
                if (intent.getBooleanExtra(UsbManager.EXTRA_PERMISSION_GRANTED, false)) {
                    if(device != null) {
                        Log.d(TAG, "Permission granted for device " + device);
                        USBConnection.getConnection(context, device);
                    }
                }
                else {
                    USBConnection.closeConnection(context);
                    Log.d(TAG, "Permission denied for device " + device);
                }
            }
        }
    }
}
