package pl.elzab.virtualcomsample.activity;

import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import pl.elzab.virtualcomsample.R;
import pl.elzab.virtualcomsample.protocol.ElzabProtocol;
import pl.elzab.virtualcomsample.Communication;

/**
 * Activity used to test Elzab Prima2 electronic scales.
 * @author ElzabSoft
 * @version 1.01
 */
public class Prima2TestActivity extends UsbSerialActivity {
    /** button to obtaint weight measurement in Angel protocol. */
    Button mButtonAngel;
    /** button to obtaint basic weight measurement in Elzab protocol. */
    Button mButtonElzabBasic;
    /** button to obtaint extended weight measurement in Elzab protocol. */
    Button mButtonElzabExtended;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_prima2_test);

        showListOnScreen();
        mDeviceOutputText = (TextView)findViewById(R.id.deviceOutputText);

        mButtonAngel = (Button)findViewById(R.id.buttonPrima2Angel);
        mButtonAngel.setOnClickListener(new View.OnClickListener() {
                                            @Override
                                            public void onClick(View arg0) {
                                                Log.d(TAG, "Clicked button for obtaining weight measurement in Angel protocol.");
                                                mDeviceOutputText.setText("");
                                                mCommunication.angelWeightMeasurement();
                                            }
                                        }
        );

        mButtonElzabBasic = (Button)findViewById(R.id.buttonPrima2ElzabStable);
        mButtonElzabBasic.setOnClickListener(new View.OnClickListener() {
                                            @Override
                                            public void onClick(View arg0) {
                                                Log.d(TAG, "Clicked button for obtaining basic weight measurement in Elzab protocol.");
                                                mDeviceOutputText.setText("");
                                                mCommunication.elzabWeightMeasurement(ElzabProtocol.ScalesNumber.SCALES_0, ElzabProtocol.MeasurementFormat.FORCE_BASIC);
                                            }
                                        }
        );

        mButtonElzabExtended = (Button)findViewById(R.id.buttonPrima2ElzabUnstable);
        mButtonElzabExtended.setOnClickListener(new View.OnClickListener() {
                                                 @Override
                                                 public void onClick(View arg0) {
                                                     Log.d(TAG, "Clicked button for obtaining extended weight measurement in Elzab protocol.");
                                                     mDeviceOutputText.setText("");
                                                     mCommunication.elzabWeightMeasurement(ElzabProtocol.ScalesNumber.SCALES_0, ElzabProtocol.MeasurementFormat.FORCE_EXTENDED);
                                                 }
                                             }
        );

        // back, close the connection
        Button buttonBack = (Button)findViewById(R.id.buttonBack);
        buttonBack.setOnClickListener(new View.OnClickListener() {
                                          @Override
                                          public void onClick(View arg0) {
                                              Intent intent = new Intent(Prima2TestActivity.this, DeviceSelectionActivity.class);
                                              startActivity(intent);
                                              finish();
                                          }
                                      }
        );

        mCommunication = new Communication(this);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_prima2_test, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }
}
