package pl.elzab.virtualcomsample.dataobject;

/**
 * Object for holding ingoing USB response data.
 * @author ElzabSoft
 * @version 1.01
 */
public class IngoingResponse {
    /** response type classifier */
    public enum ResponseType {
        /** unrecognizable response */
        UNKNOWN,
        /** timeout occured */
        TIMEOUT,
        /** angel protocol presence */
        ANGEL_PROTOCOL_PRESENCE,
        /** angel protocol weight measurement */
        ANGEL_MEASUREMENT,
        /** elzab protocol presence */
        ELZAB_PROTOCOL_PRESENCE,
        /** basic weight measurement of elzab protocol */
        ELZAB_BASIC_MEASUREMENT,
        /** extended weight measurement of elzab protocol */
        ELZAB_EXTENDED_MEASUREMENT,
        /** stx device's unique number */
	    STX_UNIQUE_NR,
        /** stx protocol error message */
        STX_ERROR,
        /** stx protocol error description */
        STX_ERROR_DESCRIPTION,
        /** stx protocol empty frame */
        STX_EMPTY_FRAME,
        /** stx protocol text coding information */
        STX_CODING_INFO,
        /** presence of device using stx protocol */
        STX_DEVICE_PRESENCE
    }

    /** response type */
    private ResponseType mResponseType;
    /** response raw data */
    private byte[] mResponseBytes;

    /** empty constructor */
    public IngoingResponse()
    {};

    /** basic constructor
     * @param responseType response type
     * @param responseBytes response raw data
     */
    public IngoingResponse(ResponseType responseType, byte[] responseBytes) {
        SetResponseType(responseType);
        mResponseBytes = responseBytes.clone();
    }

    /** getter */
    public ResponseType GetResponseType() {
        return mResponseType;
    }
    /** setter */
    public void SetResponseBytes(byte[] bytes) {
        mResponseBytes = bytes.clone();
    }
    /** setter */
    public void SetResponseType(ResponseType responseType) { mResponseType = responseType; }
    /** getter */
    public byte[] GetResponseBytes() {
        return mResponseBytes.clone();
    }
}
