package pl.elzab.virtualcomsample.dataobject;

import android.os.Parcel;
import android.os.Parcelable;

/**
 * Object that holds scales measurement data.
 * @author ElzabSoft
 * @version 1.01
 */
public class Measurement implements Parcelable {
    /** tag for logging */
    public static final String TAG = "ElzabUSB";
    /** measurement stability */
    private Stability mStability;
    /** measured weight unit */
    private Unit mUnit;
    /** measured weight */
    private Double mWeight;
    /** indicates whether the measurement is out of range */
    private boolean mOverflow;

    /** measurement unit */
    public enum Unit {
        KILOGRAM,
        POUND // lb
    }

    /** measurement stability */
    public enum Stability {
        STABLE,
        UNSTABLE,
    }

    /** empty constructor */
    public Measurement() {}

    /** parcel creator */
    public static final Parcelable.Creator CREATOR =
            new Parcelable.Creator() {
                @Override
                public StxErrorMessage createFromParcel(Parcel in) {
                    return new StxErrorMessage(in);
                }

                @Override
                public StxErrorMessage[] newArray(int size) {
                    return new StxErrorMessage[size];
                }
            };

    /** TODO dummy method */
    @Override
    public int describeContents() {
        return 0;
    }

    /** method that converts Measurement to Parcel
     * @param out output Parcel
     * @param flags flags
     */
    @Override
    public void writeToParcel(Parcel out, int flags) {
        out.writeInt(mStability.ordinal());
        out.writeInt(mUnit.ordinal());
        out.writeDouble(mWeight);
        out.writeInt(mOverflow ? 1 : 0);
    }

    /** constructor that converts Parcel to Measurement
     * @param in input Parcel
     */
    public Measurement(Parcel in) {
        mStability = in.readInt() == 0 ? Stability.STABLE : Stability.UNSTABLE;
        mUnit = in.readInt() == 0 ? Unit.KILOGRAM : Unit.POUND;
        mWeight = in.readDouble();
        mOverflow = in.readInt() > 0;
    }

    @Override
    public String toString() {
        if( mOverflow) {
            return "Wynik poza zakresem";
        }
        else if( mStability == Measurement.Stability.STABLE) {
            String unit = "";
            if(mUnit == Measurement.Unit.KILOGRAM)
                unit = "kg";
            else if(mUnit == Measurement.Unit.POUND)
                unit = "lb";
            return mWeight + unit;
        } else
            return "Wynik niestabilny";
    }

    /** getter */
    public Stability GetStability() {return mStability;}
    /** setter */
    public void SetStability(Stability stability) {mStability = stability;}
    /** getter */
    public Unit GetUnit() {return mUnit;}
    /** setter */
    public void SetUnit(Unit unit) {mUnit = unit;}
    /** getter */
    public Double GetWeight() {return mWeight;}
    /** setter */
    public void SetWeight(Double weight) {mWeight = weight;}
    /** getter */
    public boolean GetOverflow() {return mOverflow;}
    /** setter */
    public void SetOverflow(boolean overflow) {mOverflow = overflow;}
}
